pub struct Orders { /* private fields */ }Expand description
Orders namespace for order-related operations
Implementations
Sourceimpl Orders
impl Orders
Sourcepub fn list(&self) -> Request<ListOrdersResponse>
pub fn list(&self) -> Request<ListOrdersResponse>
List user’s orders
Sourcepub fn get(&self, order_id: impl Into<String>) -> Request<OpenOrder>
pub fn get(&self, order_id: impl Into<String>) -> Request<OpenOrder>
Get a specific order by ID
Sourcepub fn cancel(&self, order_id: impl Into<String>) -> CancelOrderRequest
pub fn cancel(&self, order_id: impl Into<String>) -> CancelOrderRequest
Cancel an order
Sourcepub async fn cancel_all(&self) -> Result<BatchCancelResponse, ClobError>
pub async fn cancel_all(&self) -> Result<BatchCancelResponse, ClobError>
Cancel all open orders
Sourcepub async fn cancel_market(
&self,
market: impl Into<String>,
asset_id: impl Into<String>,
) -> Result<BatchCancelResponse, ClobError>
pub async fn cancel_market( &self, market: impl Into<String>, asset_id: impl Into<String>, ) -> Result<BatchCancelResponse, ClobError>
Cancel all orders for a specific market and asset
Sourcepub fn is_scoring(
&self,
order_id: impl Into<String>,
) -> Request<OrderScoringResponse>
pub fn is_scoring( &self, order_id: impl Into<String>, ) -> Request<OrderScoringResponse>
Check if an order is being scored for rewards
Sourcepub fn are_scoring(
&self,
order_ids: impl Into<Vec<String>>,
) -> Request<Vec<OrderScoringResponse>>
pub fn are_scoring( &self, order_ids: impl Into<Vec<String>>, ) -> Request<Vec<OrderScoringResponse>>
Check if multiple orders are being scored for rewards
Sourcepub async fn cancel_many(
&self,
order_ids: impl Into<Vec<String>>,
) -> Result<BatchCancelResponse, ClobError>
pub async fn cancel_many( &self, order_ids: impl Into<Vec<String>>, ) -> Result<BatchCancelResponse, ClobError>
Cancel multiple orders by ID (up to 3000)