pub struct ListUserRewardMarkets { /* private fields */ }Expand description
Request builder for GET /rewards/user/markets.
Implementations
Sourceimpl ListUserRewardMarkets
impl ListUserRewardMarkets
Sourcepub fn maker_address(self, address: impl Into<String>) -> Self
pub fn maker_address(self, address: impl Into<String>) -> Self
Query a maker address other than the authenticated wallet.
Sourcepub fn sponsored(self, sponsored: bool) -> Self
pub fn sponsored(self, sponsored: bool) -> Self
Restrict results to sponsored reward markets (default: false).
Sourcepub fn query_text(self, q: impl Into<String>) -> Self
pub fn query_text(self, q: impl Into<String>) -> Self
Free-text search over market questions.
Sourcepub fn favorite_markets(self, value: bool) -> Self
pub fn favorite_markets(self, value: bool) -> Self
Restrict to the caller’s favorited markets (default: false).
Sourcepub fn no_competition(self, value: bool) -> Self
pub fn no_competition(self, value: bool) -> Self
Restrict to markets with no competing liquidity (default: false).
Sourcepub fn only_mergeable(self, value: bool) -> Self
pub fn only_mergeable(self, value: bool) -> Self
Restrict to markets with mergeable positions (default: false).
Sourcepub fn only_open_orders(self, value: bool) -> Self
pub fn only_open_orders(self, value: bool) -> Self
Restrict to markets where the caller has open orders (default: false).
Sourcepub fn only_open_positions(self, value: bool) -> Self
pub fn only_open_positions(self, value: bool) -> Self
Restrict to markets where the caller has open positions (default: false).
Sourcepub fn order_by(self, order_by: UserRewardMarketOrderBy) -> Self
pub fn order_by(self, order_by: UserRewardMarketOrderBy) -> Self
Sort field.
Sourcepub fn position(self, position: SortPosition) -> Self
pub fn position(self, position: SortPosition) -> Self
Sort direction.
Sourcepub fn next_cursor(self, cursor: impl Into<String>) -> Self
pub fn next_cursor(self, cursor: impl Into<String>) -> Self
Continue from a pagination cursor; "LTE=" marks the last page.