Module utils

Module utils 

Functions

calculate_market_order_amounts
Calculate maker and taker amounts for a MARKET order.
calculate_market_price
Calculate the worst price needed to fill the requested amount from the orderbook.
calculate_order_amounts
Calculate maker and taker amounts for an order using f64 arithmetic.
generate_salt
Generate random salt for orders