Functions
- calculate_
market_ order_ amounts - Calculate maker and taker amounts for a MARKET order.
- calculate_
market_ price - Calculate the worst price needed to fill the requested amount from the orderbook.
- calculate_
order_ amounts - Calculate maker and taker amounts for an order using f64 arithmetic.
- generate_
salt - Generate random salt for orders